#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-tasty-sugar-z-tasty-sugar-internal
version:              2.2.3.1
package-name:         tasty-sugar
lib-name:             tasty-sugar-internal
id:
    tasty-sugar-2.2.3.1-JB9PnRLExI9Gx7m5ys9PPh-tasty-sugar-internal

key:
    tasty-sugar-2.2.3.1-JB9PnRLExI9Gx7m5ys9PPh-tasty-sugar-internal

license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  5ea9a82b196697d4763b1280481109e7
exposed-modules:
    Test.Tasty.Sugar.Analysis Test.Tasty.Sugar.AssocCheck
    Test.Tasty.Sugar.Candidates Test.Tasty.Sugar.ExpectCheck
    Test.Tasty.Sugar.Iterations Test.Tasty.Sugar.ParamCheck
    Test.Tasty.Sugar.Ranged Test.Tasty.Sugar.Report
    Test.Tasty.Sugar.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:
    HStasty-sugar-2.2.3.1-JB9PnRLExI9Gx7m5ys9PPh-tasty-sugar-internal

depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-FJvD0WO37lG1hB3kyfoerM filepath-1.4.300.1
    kvitable-1.1.2.0-8YVKd95zxcXAyc17rCfmsd
    logict-0.8.2.0-AnsGSJta3xf5Knn3VfCpMg
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.2-y57O1yX0U1K0S9aBMDJoK text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-sugar
version:              2.2.3.1
visibility:           public
id:                   tasty-sugar-2.2.3.1-EJ3bxLIYyInJLghHMv0JhC
key:                  tasty-sugar-2.2.3.1-EJ3bxLIYyInJLghHMv0JhC
license:              ISC
copyright:            Kevin Quick
maintainer:           kquick@galois.com
author:               Kevin Quick
homepage:             https://github.com/kquick/tasty-sugar
synopsis:             Tests defined by Search Using Golden Answer References
description:

    A tasty testing framework that builds individual test configurations
    from a set of input files and expected results (golden) files along
    with associated files, where multiple expected results and
    associated files for each input file can be parameterized by
    filename.

    Additionally a tasty ingredient is supplied that can be used to show
    the search process and resulting test configurations without
    actually running the tests.

category:             Testing
abi:                  5ac8b1b0501e4e8126a58e0b8149388e
exposed:              True
exposed-modules:      Test.Tasty.Sugar
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-sugar-2.2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-sugar
hs-libraries:         HStasty-sugar-2.2.3.1-EJ3bxLIYyInJLghHMv0JhC
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    filemanip-0.3.6.3-FJvD0WO37lG1hB3kyfoerM filepath-1.4.300.1
    logict-0.8.2.0-AnsGSJta3xf5Knn3VfCpMg
    optparse-applicative-0.18.1.0-1ZOUgEBAg4Z36ZcICQWhpn
    prettyprinter-1.7.2-y57O1yX0U1K0S9aBMDJoK
    tasty-1.5.3-6nKhUbFgil18EVkHRCvth3
    tasty-sugar-2.2.3.1-JB9PnRLExI9Gx7m5ys9PPh-tasty-sugar-internal
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-tasty-sugar/html/tasty-sugar.haddock
haddock-html:         /usr/share/doc/haskell-tasty-sugar/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

